@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.3.2'; # VERSION
+our $VERSION = 'v0.3.3'; # VERSION
 
 use Moose;
 with qw(
@@ -117,7 +117,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version v0.3.2
+version v0.3.3
 
 =head1 SYNOPSIS
 
@@ -433,7 +433,7 @@ Additional documentation: Fourth line of the billing street address.
 
 Reader: country
 
-Type: MooseX::Types::Locale::Country::Alpha2Country
+Type: MooseX::Types::CyberSource::CountryCode
 
 This attribute is required.
 
