@@ -5,13 +5,13 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.3.2'; # VERSION
+our $VERSION = 'v0.3.3'; # VERSION
 
 use Moose::Role;
 use MooseX::Aliases;
 use MooseX::Types::Varchar         qw( Varchar       );
 use MooseX::Types::Email           qw( EmailAddress  );
-use MooseX::Types::Locale::Country qw( Alpha2Country );
+use MooseX::Types::CyberSource     qw( CountryCode   );
 use MooseX::Types::NetAddr::IP     qw( NetAddrIPv4   );
 
 has first_name => (
@@ -84,7 +84,7 @@ has country => (
 	required => 1,
 	coerce   => 1,
 	is       => 'ro',
-	isa      => Alpha2Country,
+	isa      => CountryCode,
 	documentation => 'ISO 2 character country code '
 		. '(as it would apply to a credit card billing statement)',
 );
@@ -153,7 +153,7 @@ Business::CyberSource::Request::Role::BillingInfo - Role for requests that requi
 
 =head1 VERSION
 
-version v0.3.2
+version v0.3.3
 
 =head1 BUGS
 
